@@ -26,9 +26,7 @@ class AppSettings:
 
     @property
     def CONTEXT_BEHAVIOR(self):
-        raw_value = self.settings.setdefault(
-            "context_behavior", ContextBehavior.GLOBAL.value
-        )
+        raw_value = self.settings.setdefault("context_behavior", ContextBehavior.GLOBAL.value)
         return self._validate_context_behavior(raw_value)
 
     def _validate_context_behavior(self, raw_value):
@@ -36,9 +34,7 @@ class AppSettings:
             return ContextBehavior(raw_value)
         except ValueError:
             valid_values = [behavior.value for behavior in ContextBehavior]
-            raise ValueError(
-                f"Invalid context behavior: {raw_value}. Valid options are {valid_values}"
-            )
+            raise ValueError(f"Invalid context behavior: {raw_value}. Valid options are {valid_values}")
 
 
 app_settings = AppSettings()
